AstBundler class
Constructors
-
AstBundler({Set<
String> bridgedLibraries = const {}, Map<String, String> explicitSources = const {}, String? packageName, String? projectRoot, AstBundlerConfig config = const AstBundlerConfig(), FileAccessValidator? fileAccessValidator, AstConverter? converter}) - Creates an AstBundler.
Properties
-
bridgedLibraries
→ Set<
String> -
Library URIs handled by native bridges at runtime (skipped during bundling).
final
- config → AstBundlerConfig
-
Configuration for import resolution behavior.
final
-
explicitSources
→ Map<
String, String> -
Additional source code keyed by URI string, for imports that cannot
be resolved from disk.
final
- fileAccessValidator → FileAccessValidator?
-
Optional validator for file system access.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- packageName → String?
-
The package name of the entry point project.
Used to determine which
package:*imports are "same-package" and should be auto-included.final - projectRoot → String?
-
The project root directory for resolving file paths.
This is the directory containing
pubspec.yaml.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createFromFile(
String entryPointPath) → Future< AstBundle> - Creates an AstBundle from a file path.
-
createFromSource(
String source, {String sourcePath = 'main.dart'}) → Future< AstBundle> - Creates an AstBundle from a source code string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited