AstBundlerConfig class
Configuration for AstBundler import resolution behavior.
Controls which import schemes are auto-resolved, which are skipped, and what constitutes an error.
Constructors
-
AstBundlerConfig({Set<
String> stdlibSchemes = const {'dart'}, int maxImportDepth = 64, bool followPartDirectives = true}) -
Default configuration.
const
Properties
- followPartDirectives → bool
-
Whether to include part directives when scanning for imports.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxImportDepth → int
-
Maximum recursion depth for following imports.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stdlibSchemes
→ Set<
String> -
URI schemes that are always skipped (stdlib, always available at runtime).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited